@@ -1,10 +1,11 @@
 #!/bin/bash
 
 RM_PO="po/Makefile* po/POTFILES"
-RM_SRC="src/Makefile src/.deps"
-RM_GLADE="Makefile COPYING INSTALL\
+RM_SRC="src/Makefile src/Makefile.in src/.deps src/interface.?.bak"
+RM_GLADE="Makefile Makefile.in COPYING INSTALL depcomp\
   aclocal.m4 auto*.cache config.* configure mkinstalldirs\
-  missing install-sh stamp-h stamp-h? .deps"
+  missing install-sh stamp-h stamp-h? .deps\
+  *.glade.bak *.gladep.bak"
 RM_LIST="$RM_PO $RM_SRC $RM_GLADE"
 
 clean(){
@@ -24,9 +25,6 @@ cd -
 cd ./vncviewer
 clean
 cd -
-cd ./libvncauth
-clean
-cd -
 
 case $1 in
   all)
@@ -39,10 +37,8 @@ case $1 in
     rm -rf $RM_LIST;\
     cd -;\
     cd ./vncviewer;\
-    rm Makefile;\
-    cd -;\
-    cd ./libvncauth;\
-    rm Makefile;\
+    echo "rm $RM_LIST";\
+    rm -rf $RM_LIST;\
     cd -
     ;;
 esac
