@@ -34,6 +34,7 @@
 #define STRLENGTH	64
 #define IF_LENGTH   16  // interface name and ip length
 #define SLEEP		2
+#define MACADDR_SIZE    6
 
 #define START		1
 #define STOP		0
@@ -53,16 +54,16 @@
 #define CAST_STOP       2
 
 /* state parameter */
-#define RESENDSTATE	0x01	/* 饤Ȥ̤׵ */
-#define RECSTATE	0x02	/* Ͽ */
-#define CTRLSTATE	0x04	/*  */
-#define VIEWSTATE	0x08	/* ̳ɽ */
-#define FILESTATE	0x10	/* եž */
-#define SENDSTATE	0x20    /* ۿ */
-#define RECVSTATE	0x40	/* ۿμ */
-#define LOCKSTATE	0x80	/* å */
+#define RESENDSTATE	0x0001	/* クライアントからの全画面の要求 */
+#define CTRLSTATE	0x0004	/* 画面操作 */
+#define VIEWSTATE	0x0008	/* 画面拡大表示 */
+#define FILESTATE	0x0010	/* ファイル転送 */
+#define SENDSTATE	0x0020	/* 画面配信の送信者 */
+#define RECVSTATE	0x0040	/* 画面配信の受信者 */
+#define LOCKSTATE	0x0080	/* ロック中 */
+#define MCTRLSTATE	0x0100	/* 複数画面操作 */
 
-/* ˤ륯饤ȥơ */
+/* 画像処理によるクライアントステータス */
 #define NORMAL      0
 #define FREEZE      1
 #define IRREGULAR   2
@@ -92,13 +93,14 @@
 #define GETRESEND(Num)		(server_CB.client_grp[(Num)]->state & RESENDSTATE)?1:0
 #define SETRESEND(Num, Flag)	(Flag)?(server_CB.client_grp[(Num)]->state |= RESENDSTATE):\
                                         (server_CB.client_grp[(Num)]->state &= ~RESENDSTATE)
-#define GETREC(Num)		(server_CB.client_grp[(Num)]->state & RECSTATE)?1:0
-#define SETREC(Num, Flag)	(Flag)?(server_CB.client_grp[(Num)]->state |= RECSTATE):\
-                                        (server_CB.client_grp[(Num)]->state &= ~RECSTATE)
 
 #define GETFILE(Num)		(server_CB.client_grp[(Num)]->state & FILESTATE)?1:0
 #define SETFILE(Num, Flag)	(Flag)?(server_CB.client_grp[(Num)]->state |= FILESTATE):\
 
+#define GETMCTRL(Num)		(server_CB.client_grp[(Num)]->state & MCTRLSTATE)?1:0
+#define SETMCTRL(Num, Flag)	(Flag)?(server_CB.client_grp[(Num)]->state |= MCTRLSTATE):\
+                                        (server_CB.client_grp[(Num)]->state &= ~MCTRLSTATE)
+
 /* for client */
 #define GETLOCK_C		(client_CB.state & LOCKSTATE)?1:0
 #define SETLOCK_C(Flag)		(Flag)?(client_CB.state |= LOCKSTATE):(client_CB.state &= ~LOCKSTATE)
@@ -106,11 +108,23 @@
 #define SETRECV_C(Flag)		(Flag)?(client_CB.state |= RECVSTATE):(client_CB.state &= ~RECVSTATE)
 #define GETRESEND_C		(client_CB.state & RESENDSTATE)?1:0
 #define SETRESEND_C(Flag)	(Flag)?(client_CB.state |= RESENDSTATE):(client_CB.state &= ~RESENDSTATE)
-#define GETREC_C		(client_CB.state & RECSTATE)?1:0
-#define SETREC_C(Flag)		(Flag)?(client_CB.state |= RECSTATE):(client_CB.state &= ~RECSTATE)
 #define GETFILE_C		(client_CB.state & FILESTATE)?1:0
 #define SETFILE_C(Flag)		(Flag)?(client_CB.state |= FILESTATE):(client_CB.state &= ~FILESTATE)
 
+/* waiting interval for established connection (second) */
+#define VNCCONNECT_INTERVAL 3
+
+/* exproc */
+#define EXPROC_PORT 55555
+#define EXPROC_MSG_REGISTER       1
+#define EXPROC_MSG_EXPAND         2
+#define EXPROC_MSG_LIST           3
+#define EXPROC_MSG_SENDSCREEN     4
+#define EXPROC_MSG_OPERATE        5
+#define EXPROC_MSG_LOCK           6
+#define EXPROC_MSG_STATUS_CHANGED 7
+#define EXPROC_MSG_DISCONNECT     9
+#define EXPROC_MSG_WINDOW_CHANGED 10
 
 typedef struct {
 	CARD8	type;
@@ -124,6 +138,7 @@ typedef struct {
 	CARD8	type;
 	CARD8	length;
 	CARD8	client_ID[IDLENGTH];
+	CARD8	mac_addr[MACADDR_SIZE];
 } ClientAdv;
 
 typedef struct {
@@ -137,22 +152,6 @@ typedef struct {
 	rfbPixelFormat pixelFormat;
 } CastAdv;
 
-typedef struct {
-	CARD8	type;
-	CARD8	flag;
-	CARD8	rectime;
-	CARD8	fps;
-	CARD8	geometry[IDLENGTH];
-} RecAdv;
-
-typedef struct {
-	CARD8	type;
-	CARD8	flag;
-	size_t	fsize;
-	CARD8	fname[STRLENGTH];
-	CARD8	data[MAXBUF];
-} FileAdv;
-
 typedef struct {
 	CARD8	type;
 	CARD8	flag;
@@ -175,7 +174,6 @@ typedef struct {
 	CARD8 flag;
 } VncConnAdv;
 
-#if IMAGE_PROC
 typedef struct {
   CARD8 type;
   CARD8 flag;
@@ -189,8 +187,15 @@ typedef struct {
 typedef struct {
 	CARD8 type;
 	CARD8 flag;
-} HistogramRequestAdv;
-#endif
+} OperateStateDecisionRequestAdv;
+
+typedef struct {
+	CARD8 type;
+	CARD8 flag;
+	CARD16 getimage_interval; 
+	CARD8 freeze_count;
+	CARD8 padding;
+} OperateStateDecisionAdv;
 
 typedef struct {
 	CARD8 type;
@@ -203,34 +208,38 @@ typedef struct {
 } HelpSetAdv;
 
 struct server_cb {
-	struct client_grp *client_grp[MAXCLIENT];	/* 饤Ⱦ */
-	CARD32 advertise_ip;				/* еưΥɥ쥹 */
-	CARD16 advertise_port;				/* еưΥݡ */
-	CARD32 cstdsp[MAXCLIENT];			/* ǥץ */
-	CARD32 casting_ip[MAXCLIENT];			/* ɥ쥹 */
-	CARD16 casting_port;				/* ݡ */
-	CARD8 server_ID[IDLENGTH];			/* ID */
-	CARD16 server_port;				/* listenݡ */
-	CARD32 lsndsp;					/* listenǥץ */
-	CARD32 g_lsndsp;				/* listenǥץ(gtk) */
-	CARD8 user_num;					/* 饤³ */
+	struct client_grp *client_grp[MAXCLIENT];	/* クライアント情報 */
+	CARD32 advertise_ip;				/* サーバ起動通知アドレス */
+	CARD16 advertise_port;				/* サーバ起動通知ポート */
+	CARD32 cstdsp[MAXCLIENT];			/* 画面送信ディスクリプタ */
+	CARD32 casting_ip[MAXCLIENT];			/* 画面送信アドレス */
+	CARD16 casting_port;				/* 画面送信ポート */
+	CARD8 server_ID[IDLENGTH];			/* サーバID */
+	CARD16 server_port;				/* listenポート */
+	CARD32 lsndsp;					/* listenディスクリプタ */
+	CARD32 g_lsndsp;				/* listenディスクリプタ(gtk) */
+	CARD8 user_num;					/* クライアント接続数 */
 	//CARD32 testdsp;
 	//CARD8 flag;
 	CARD8 processingNum;
-	CARD8 cast_src[MAXCLIENT];			/* 롼פ饤ֹ */
-	struct timeval basetime;			/* RTT¬δȤʤ */
+	CARD8 cast_src[MAXCLIENT];			/* 画面送信グループの送信元クライアント番号 */
+	struct timeval basetime;			/* RTT計測の基準となる時間 */
 	CARD8 DB_Host[16];
-	CARD32 DB_Port;
+	CARD16 DB_Port;
 	CARD8 DB_Name[16];
 	CARD8 DB_Pass[16];
 	CARD8 DB_Database[16];
+	CARD8 ope_flag;
+	CARD16 opestate_interval;
+	CARD16 getimage_interval;
+	CARD8 freeze_count;
 };
 
 struct client_grp {
 	CARD8 client_ID[IDLENGTH];
 	CARD32 client_ip;
 	CARD16 client_port;
-	CARD8 state;
+	CARD16 state;
 	CARD32 vncdsp;
 	CARD32 ctldsp;
 	CARD32 g_vncdsp;
@@ -245,12 +254,12 @@ struct client_grp {
 	gint resend_tag;
 	int shm_id;
 	FILE *fp;
-//#if IMAGE_PROC /* Ū˲ */
-    CARD8 client_status;
-    CARD32 histogram_h[256];
-    CARD32 histogram_s[256];
-    CARD32 histogram_v[256];
-//#endif
+	CARD8 client_status;
+	CARD32 histogram_h[256];
+	CARD32 histogram_s[256];
+	CARD32 histogram_v[256];
+	CARD8 client_macaddr[MACADDR_SIZE];
+	guint vncconnect_tag;
 };
 
 struct client_cb {
@@ -274,13 +283,14 @@ struct client_cb {
 	CARD32 connectstate;
 	rfbServerInitMsg serverInitMsg;
 	rfbPixelFormat serverFormat;
-	CARD16 del_pk_num;				/* ˴줿ѥåȿ */
-#if IMAGE_PROC
-    CARD8 client_status;
-    CARD32 histogram_h[256];
-    CARD32 histogram_s[256];
-    CARD32 histogram_v[256];
-#endif
+	CARD16 del_pk_num;				/* 画面送信で破棄されたパケット数 */
+	CARD8 client_status;
+	CARD32 histogram_h[256];
+	CARD32 histogram_s[256];
+	CARD32 histogram_v[256];
+	CARD8 ope_flag;
+	CARD16 getimage_interval;
+	CARD8 freeze_count;
 };
 
 struct Draw_Info {
@@ -301,7 +311,6 @@ extern void ConnectVNC (struct sockaddr_in, int, int);
 int CreateMultiSockToSend (unsigned int ip, int port);
 extern void SendCastMsg (char flag, int clientNum, char fullscreen);
 extern void SendLockMsg (char flag, int clientNum);
-extern void SendRecMsg (char flag, int clientNum, int rectime,int fps,char* geometry);
 extern void SendAllowMsg (int clientNum, char *buf);
 extern void CutVNC (int clientNum);
 extern void SendVncMsg (int clientNum);
@@ -311,6 +320,14 @@ extern void sem_lock (void);
 extern void sem_unlock (void);
 extern struct Shm_asym *shm_asym[MAXCLIENT];
 extern void resendCallback (gpointer cnum);
+extern char server_ifname[IF_LENGTH];
+extern char server_ifaddr[IF_LENGTH];
+extern void SendOpeStateDecisionMsg (int clientNum);
+extern int mac2id(unsigned char *maddr);
+extern void* exproc_callback(void *args);
+extern unsigned char makeClientStatus(int clientNum);
+extern void exprocSendStatusChangedMsg(int clientNum, unsigned char status);
+extern void exprocSendWindowChangedMsg(unsigned char windowID, unsigned char status);
 
 #include <sys/shm.h>
 #include <unistd.h>
@@ -320,8 +337,6 @@ extern void resendCallback (gpointer cnum);
 
 /* sockets.c */
 extern gint gdksock;
-//extern int buffered;
-static int buffered = 0;
 
 /* vncviewer.c */
 extern int vnc_main(int argc, char **argv);
@@ -335,10 +350,8 @@ extern void CloseVNCServer (void);
 int adjustColorBitShift(short server_bits, short client_bits);
 extern int auto_flag;
 extern int notice_flag;
-//void start_record(void);
-void start_record(int framerate, char *geometry, char *path);
-void stop_record(void);
-void changeTwoDigit(char *string, int num);
+extern char client_ifname[IF_LENGTH];
+extern char client_ifaddr[IF_LENGTH];
 
 /* listen.c */
 extern void doListen();
@@ -377,8 +390,12 @@ struct Shm_asym {
 extern void calcRateCallback (gpointer cnum);
 
 /* sc_common.c */
+#include <gdk/gdkx.h>
 int get_ifaddr(char *interface, char *addr);
-
+int get_macaddr(char *interface, unsigned char *addr);
+int find_macaddr(int sock, unsigned char *addr);
+void show_gtkwindow(GtkWidget *widget);
+int move_gtkwindow(GtkWidget *widget, int monitor);
 
 /* init_client.c */
 void DesktopInitForClient(void);
@@ -400,9 +417,21 @@ void makeTable( int p, int x, int y );
 void ChangeLabel(int p, int d, char *name);
 extern int exDB_flag;
 extern int Resend_flag;
+extern int mainwindowMonitor;
+extern int mainwindowShowFlag;
+extern int exwindowMonitor;
+extern int exwindowShowFlag;
+extern int auto_expand_flag;
+extern int use_myself_client;
 extern GtkWidget *user_list[TAB_MAX];
 extern GtkWidget *client_name_list[TAB_MAX][ROW_MAX * COLUMN_MAX];
 extern GtkWidget *group_name_list[TAB_MAX];
+void runExpand(int flag, unsigned char *maddr);
+void runList(unsigned char **maddr, int len);
+void runSendScreen(int flag, unsigned char **maddr, int len);
+void runOperate(int flag, unsigned char **maddr, int len);
+void runLock(int flag, unsigned char *maddr);
+void runDisconnect(unsigned char *maddr);
 
 /* callbacks.c(server) */
 GdkPixmap *gdkpixmap[TAB_MAX][ROW_MAX * COLUMN_MAX];
