@@ -265,11 +265,11 @@ typedef struct {
 #define rfbBell			2
 #define rfbServerCutText	3
 
-#define rfbFileAdv		14
 #define rfbClientAdv		15
 #define rfbClientExist		16
 #define rfbHistogramAdv		18
 #define rfbHelpAdv		20
+#define rfbOperateStateDecisionRequestAdv 22
 
 /* client -> server */
 #define rfbSetPixelFormat	0
@@ -285,9 +285,8 @@ typedef struct {
 #define rfbAllowAdv		10
 #define rfbCastAdv		11
 #define rfbLockAdv		12
-#define rfbRecAdv		13
 #define rfbVncConnAdv		17
-#define rfbHistogramRequestAdv	19
+#define rfbOperateStateDecisionAdv 23
 
 
 /*****************************************************************************
