@@ -29,8 +29,8 @@ extern PangoFontDescription *font_dsp;
 
 
 /****************************************************************
- *Ф줿ɽ뤿ΥɥǻѤ
- *ؿ
+ *サーバから送信された画像を表示するためのウィンドウで使用する
+ *関数
  ****************************************************************/
 
 gboolean
@@ -73,6 +73,12 @@ on_drawingarea_expose_event           (GtkWidget       *widget,
                                         GdkEventExpose  *event,
                                         gpointer         user_data)
 {
+  // 画像の縮小
+  if (gdkimage[0] != NULL) {
+    draw_image(gdkpixmap[0][0], gdkGC, gdkimage[0], 0, 0, 0, 0,
+               gdkimage[0]->width, gdkimage[0]->height);
+  }
+  // ウィンドウの再描画
   gdk_draw_pixmap(widget->window,
 		  widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
 		  gdkpixmap[0][0],
@@ -85,7 +91,7 @@ on_drawingarea_expose_event           (GtkWidget       *widget,
 
 
 /****************************************************************
- *IDϥǻѤؿ
+ *ID入力ダイアログで使用する関数
  ****************************************************************/
 gboolean
 on_dialog_IDinput_delete_event         (GtkWidget       *widget,
@@ -101,12 +107,25 @@ on_dialog_IDinput_entry_editing_done   (GtkCellEditable *celleditable,
                                         gpointer         user_data)
 {
   memset(clientID, 0, sizeof(clientID));
-  if (strlen((char *)gtk_entry_get_text(GTK_ENTRY(celleditable))) < 1) {
+  strncpy(clientID, (char *)gtk_entry_get_text(GTK_ENTRY(celleditable)), IDLENGTH);
+
+  if (strlen(clientID) < 1) {
     return;
   }
-  strncpy(clientID, (char *)gtk_entry_get_text(GTK_ENTRY(celleditable)), IDLENGTH);
+  memcpy((char *)client_CB.client_ID, clientID, IDLENGTH);
   printf("clientID(edit done): %s\n", clientID);
 
+  gtk_grab_remove(dialog_IDinput);
+  gtk_widget_destroy(dialog_IDinput);
+  gtk_main_quit();
+  if (client_CB.mltdsp != 0)
+    client_CB.g_mltdsp = gdk_input_add (client_CB.mltdsp, GDK_INPUT_READ, \
+					(GdkInputFunction)GetMultiVNCServerMsg, (gpointer)client_CB.mltdsp);
+  dialog_wait = create_dialog_wait();
+  gtk_widget_show(dialog_wait);
+  show_gtkwindow(dialog_wait);
+  gtk_grab_add(dialog_wait);
+  draw_string_to_mini_window(_("Wait"));
 }
 
 
@@ -141,6 +160,7 @@ on_dialog_IDinput_buttonOK_clicked     (GtkButton       *button,
 					(GdkInputFunction)GetMultiVNCServerMsg, (gpointer)client_CB.mltdsp);
   dialog_wait = create_dialog_wait();
   gtk_widget_show(dialog_wait);
+  show_gtkwindow(dialog_wait);
   gtk_grab_add(dialog_wait);
   draw_string_to_mini_window(_("Wait"));
 }
@@ -158,7 +178,7 @@ on_dialog_IDinput_buttonCancel_clicked (GtkButton       *button,
 
 
 /****************************************************************
- *ԵפΥåɽ뤿ΥǻѤؿ
+ *「待機中」のメッセージを表示するためのダイアログで使用する関数
  ****************************************************************/
 gboolean
 on_dialog_wait_delete_event            (GtkWidget       *widget,
@@ -180,6 +200,7 @@ on_dialog_wait_buttonStop_clicked      (GtkButton       *button,
 
   dialog_IDinput = create_dialog_IDinput();
   gtk_widget_show(dialog_IDinput);
+  show_gtkwindow(dialog_IDinput);
   gtk_grab_add(dialog_IDinput);
   draw_string_to_mini_window(_("Input ID"));
   gtk_main();
@@ -187,7 +208,7 @@ on_dialog_wait_buttonStop_clicked      (GtkButton       *button,
 
 
 /****************************************************************
- *³륵Фǧ뤿ΥǻѤؿ
+ *接続するサーバを確認するためのダイアログで使用する関数
  ****************************************************************/
 
 void open_dialog_recvAdv(char *server_ID)
@@ -200,6 +221,7 @@ void open_dialog_recvAdv(char *server_ID)
   sprintf(recvAdv_msg, _("Server Name : %s\n\nDo you connect to this server?"), server_ID);
   gtk_label_set_text(GTK_LABEL(recvAdv_label), recvAdv_msg);
   gtk_widget_show(dialog_recvAdv);
+  show_gtkwindow(dialog_recvAdv);
   gtk_grab_add(dialog_recvAdv);
   gtk_main();
 }
@@ -212,6 +234,7 @@ on_dialog_recvAdv_delete_event         (GtkWidget       *widget,
 {
   dialog_exit = create_dialog_exit();
   gtk_widget_show(dialog_exit);
+  show_gtkwindow(dialog_exit);
   gtk_grab_add(dialog_exit);
 //  draw_string_to_mini_window(_("Quit"));
 
@@ -242,14 +265,15 @@ on_dialog_recvAdv_buttonCancel_clicked (GtkButton       *button,
 
   dialog_wait = create_dialog_wait();
   gtk_widget_show(dialog_wait);
+  show_gtkwindow(dialog_wait);
   gtk_grab_add(dialog_wait);
   draw_string_to_mini_window(_("Wait"));
 }
 
 
 /****************************************************************
- *IDκϤ¥åɽ뤿ΥǻѤ
- *ؿ
+ *IDの再入力を促すメッセージを表示するためのダイアログで使用する
+ *関数
  ****************************************************************/
 gboolean
 on_dialog_inputmiss_delete_event       (GtkWidget       *widget,
@@ -271,11 +295,11 @@ on_dialog_inputmiss_buttonOK_clicked   (GtkButton       *button,
 
 
 /****************************************************************
- *饤ȥåǽǻѤؿ
+ *クライアントロック機能で使用される関数
  ****************************************************************/
 
 /*
-  ޥݥ󥿤Ĥ뤿Υɥκ
+  マウスポインタを閉じ込めるためのウィンドウの作成
  */
 void
 create_lock_window (void)
@@ -286,6 +310,11 @@ create_lock_window (void)
 //  gtk_window_set_title (GTK_WINDOW (lock_window), _("MultiVNC \346\223\215\344\275\234\343\203\255\343\203\203\343\202\257\347\224\250\343\202\246\343\202\243\343\203\263\343\203\211\343\202\246"));
   gtk_window_set_title (GTK_WINDOW (lock_window), _("MultiVNC Lock"));
 
+  gtk_window_set_position(GTK_WINDOW(lock_window), GTK_WIN_POS_CENTER_ALWAYS);
+  gtk_window_set_decorated(GTK_WINDOW(lock_window), FALSE);
+  gtk_window_set_keep_above(GTK_WINDOW(lock_window), TRUE);
+  gtk_window_set_type_hint(GTK_WINDOW(lock_window), GDK_WINDOW_TYPE_HINT_MENU);
+
   lock_screen = gtk_drawing_area_new ();
   gtk_widget_show (lock_screen);
   gtk_container_add (GTK_CONTAINER (lock_window), lock_screen);
@@ -299,6 +328,7 @@ create_lock_window (void)
 
   draw_string_to_mini_window(_("Lock"));
   gtk_widget_show(lock_window);
+  show_gtkwindow(lock_window);
   gtk_grab_add(lock_window);
 }
 
@@ -351,7 +381,7 @@ on_lock_screen_expose_event       (GtkWidget       *widget,
 		  event->area.x, event->area.y,
 		  event->area.width, event->area.height);
 
-  /* ޥݥ󥿤 */
+  /* マウスポインタの捕獲 */
   gdk_keyboard_grab(widget->window, FALSE, GDK_CURRENT_TIME);
   gdk_pointer_grab(widget->window, FALSE, 0, gtk_widget_get_parent_window(widget), NULL, GDK_CURRENT_TIME);
 
@@ -360,23 +390,23 @@ on_lock_screen_expose_event       (GtkWidget       *widget,
 
 
 /*
-  ޥݥ󥿤åwindowĤؿ
+  マウスポインタをロック用windowに閉じ込める関数
  */
 void
 start_lock(void)
 {
-  /* ޥݥ󥿤Υå */
+  /* マウスポインタを以前のロックから解放 */
   gdk_keyboard_ungrab(GDK_CURRENT_TIME);
   gdk_pointer_ungrab(GDK_CURRENT_TIME);
 
-  /* ޥݥ󥿤 */
+  /* マウスポインタの捕獲 */
   gdk_keyboard_grab(lock_screen->window, FALSE, GDK_CURRENT_TIME);
   gdk_pointer_grab(lock_screen->window, FALSE, 0, gtk_widget_get_parent_window(lock_screen), NULL, GDK_CURRENT_TIME);
 }
 
 
 /*
-  åؿ
+  ロックを解除する関数
  */
 void
 stop_lock(void)
@@ -396,11 +426,11 @@ stop_lock(void)
 
 
 /****************************************************************
- *ߤξ֤ɽ륦ɥ(mini_window)ǻѤؿ
+ *現在の状態を表示するウィンドウ(mini_window)で使用する関数
  ****************************************************************/
 
 /*
-  mini_windowκ
+  mini_windowの作成
  */
 GtkWidget*
 create_mini_window (void)
@@ -437,6 +467,7 @@ on_mini_window_delete_event            (GtkWidget       *widget,
 {
   dialog_exit = create_dialog_exit();
   gtk_widget_show(dialog_exit);
+  show_gtkwindow(dialog_exit);
   gtk_grab_add(dialog_exit);
 
   return TRUE;
@@ -483,14 +514,13 @@ on_mini_drawingarea_expose_event       (GtkWidget       *widget,
 
 
 /*
-  mini_window˥åɽؿ
+  mini_windowにメッセージを表示する関数
  */
 void
 draw_string_to_mini_window(char *string)
 {
   GdkRectangle gdkrect;
   GdkGC *gc;
-  GdkColor color;
   const char* fontsname = "Bitstream Vesa Sans 14";
 //  const char* fontsname = "IPAUIGothic 24";
   font_dsp = pango_font_description_from_string(fontsname);
@@ -513,18 +543,6 @@ draw_string_to_mini_window(char *string)
   }
 }
 
-// 1.4.2 non implementation
-void change_status_mini_window() {
-    char status[STRLENGTH];
-    switch (client_CB.state) {
-        case 0:
-            strcpy(status, _("Wait"));
-            break;
-//        default:
-    }
-    draw_string_to_mini_window(status);
-}
-
 gboolean
 on_dialog_exit_delete_event            (GtkWidget       *widget,
                                         GdkEvent        *event,
