@@ -3,6 +3,7 @@
 
 void makeTable(int, int, int);
 void ChangeLabel(int p, int d, char *name);
+void add_to_dialog_viewset(int cnum);
 
 gboolean
 on_main_drawingarea_configure_event        (GtkWidget       *widget,
@@ -39,11 +40,6 @@ on_window_ex_key_release_event           (GtkWidget       *widget,
                                         GdkEventKey     *event,
                                         gpointer         user_data);
 
-gboolean
-on_window_ex_focus_in_event              (GtkWidget       *widget,
-                                        GdkEventFocus   *event,
-                                        gpointer         user_data);
-
 gboolean
 on_window_ex_focus_out_event             (GtkWidget       *widget,
                                         GdkEventFocus   *event,
@@ -53,18 +49,10 @@ void
 on_quit_activate                       (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_network_activate                    (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_viewset_activate                    (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_function_activate                   (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_send_activate                       (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -73,18 +61,10 @@ void
 on_lock_activate                       (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_usage_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_version_activate                    (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_save_activate                       (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_dialog_viewset_list_select_child    (GtkList         *list,
                                         GtkWidget       *widget,
@@ -144,10 +124,6 @@ void
 on_screen_send_stop_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_screen_record_activate              (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_dialog_send_checkbutton1_toggled    (GtkToggleButton *togglebutton,
 		                        gpointer         user_data);
@@ -181,19 +157,6 @@ void
 on_dialog_lock_checkbutton2_toggled    (GtkToggleButton *togglebutton,
 		                        gpointer         user_data);
 
-gboolean
-on_dialog_sendstop_delete_event        (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
-void
-on_dialog_sendstop_buttonOK_clicked    (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_sendstop_buttonCancel_clicked(GtkButton       *button,
-                                        gpointer         user_data);
-
 gboolean
 on_main_window_delete_event            (GtkWidget       *widget,
                                         GdkEvent        *event,
@@ -323,10 +286,6 @@ void
 on_dialog_version_buttonOK_clicked     (GtkButton       *button,
                                         gpointer         user_data);
 
-void
-on_save_activate                       (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_dialog_send_fullscreen_radiobutton_toggled
                                         (GtkToggleButton *togglebutton,
@@ -431,114 +390,43 @@ on_aspectframe_expose_event            (GtkWidget       *widget,
                                         GdkEventExpose  *event,
                                         gpointer         user_data);
 
-void
-on_spinbutton_rec_time_editing_done    (GtkCellEditable *celleditable,
-                                        gpointer         user_data);
-
-void
-on_dialog_rec_button_ok_clicked        (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_rec_button_cancel_clicked    (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_rec_button_apply_clicked     (GtkButton       *button,
-                                        gpointer         user_data);
-
-gboolean
-on_dialog_record_delete_event          (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
-void
-on_item_rec_activate                   (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_screen_record_activate              (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-gboolean
-on_dialog_notice_delete_event          (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
-void
-on_okbutton1_clicked                   (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_notify_okbutton_clicked      (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_record_checkbutton0_toggled  (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
 void
 on_dialog_lock_checkbutton0_toggled    (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
-void
-on_dialog_rec_button_clicked           (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_rec_button_close_clicked     (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_stop_button_clicked          (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_close_button_clicked         (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_rec_stop_button_clicked      (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_rec_close_button_clicked     (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_rec_start_button_clicked     (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_rec_button_clicked           (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_spinbutton_fps_editing_done         (GtkCellEditable *celleditable,
-                                        gpointer         user_data);
-
-void
-on_combo_entry1_editing_done           (GtkCellEditable *celleditable,
-                                        gpointer         user_data);
-
-void
-on_dialog_rec_start_button_clicked     (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_rec_stop_button_clicked      (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_dialog_rec_close_button_clicked     (GtkButton       *button,
-                                        gpointer         user_data);
-
-gboolean
-on_dialog_record_delete_event          (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
 gboolean
 on_frame_ulist_press_event             (GtkWidget       *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data);
+
+gboolean
+on_dialog_opeState_delete_event        (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+void
+on_opeState_activate                   (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_dialog_opeState_buttonApply_clicked (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_opeState_buttonCancel_clicked
+                                        (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_opeState_buttonOK_clicked    (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_main_window_configure_event         (GtkWidget       *widget,
+                                        GdkEventConfigure *event,
+                                        gpointer         user_data);
+
+gboolean
+on_window_ex_configure_event           (GtkWidget       *widget,
+                                        GdkEventConfigure *event,
+                                        gpointer         user_data);
